@@ -1,9 +1,9 @@
-# -*- coding: ISO-8859-15 -*-
+# -*- coding: utf-8 -*-
 # =================================================================
 #
 # Authors: Tom Kralidis <tomkralidis@gmail.com>
 #
-# Copyright (c) 2013 Tom Kralidis
+# Copyright (c) 2015 Tom Kralidis
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -27,4 +27,5 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 #
 # =================================================================
-__all__ = ['atom', 'dif', 'fgdc']
+
+__all__ = ['atom', 'dif', 'fgdc', 'gm03']
