@@ -34,11 +34,9 @@
 
 import logging
 import os
-from six.moves.urllib.parse import parse_qsl
-from six.moves.urllib.parse import splitquery
-from six.moves.urllib.parse import urlparse
-from six import StringIO
-from six.moves.configparser import SafeConfigParser
+from urllib.parse import parse_qsl, splitquery, urlparse
+from io import StringIO
+import configparser
 import sys
 from time import time
 import wsgiref.util
@@ -52,6 +50,16 @@ from pycsw.ogc.csw import csw2, csw3
 
 LOGGER = logging.getLogger(__name__)
 
+class EnvInterpolation(configparser.BasicInterpolation):
+    """
+    Interpolation which expands environment variables in values.
+    from: https://stackoverflow.com/a/49529659
+    """
+
+    def before_get(self, parser, section, option, value, defaults):
+        value = super().before_get(parser, section, option, value, defaults)
+        return os.path.expandvars(value)
+
 
 class Csw(object):
     """ Base CSW server """
@@ -102,10 +110,11 @@ class Csw(object):
         # load user configuration
         try:
             LOGGER.info('Loading user configuration')
-            if isinstance(rtconfig, SafeConfigParser):  # serialized already
+            if isinstance(rtconfig, configparser.ConfigParser):  # serialized already
                 self.config = rtconfig
             else:
-                self.config = SafeConfigParser()
+                self.config = configparser.ConfigParser(
+                    interpolation=EnvInterpolation())
                 if isinstance(rtconfig, dict):  # dictionary
                     for section, options in rtconfig.items():
                         self.config.add_section(section)
@@ -114,7 +123,7 @@ class Csw(object):
                 else:  # configuration file
                     import codecs
                     with codecs.open(rtconfig, encoding='utf-8') as scp:
-                        self.config.readfp(scp)
+                        self.config.read_file(scp)
         except Exception as err:
             msg = 'Could not load configuration'
             LOGGER.exception('%s %s: %s', msg, rtconfig, err)
@@ -132,6 +141,8 @@ class Csw(object):
         self.context.pycsw_home = self.config.get('server', 'home')
         self.context.url = self.config.get('server', 'url')
 
+        self.context.server = self
+
         log.setup_logger(self.config)
 
         LOGGER.info('running configuration %s', rtconfig)
