@@ -33,7 +33,7 @@ from collections import namedtuple
 import logging
 import os
 import re
-from six.moves import configparser
+import configparser
 
 import apipkg
 import pytest
@@ -192,9 +192,9 @@ def configuration(request, tests_directory, log_level):
     """
 
     config_path = request.param
-    config = configparser.SafeConfigParser()
+    config = configparser.ConfigParser()
     with codecs.open(config_path, encoding="utf-8") as fh:
-        config.readfp(fh)
+        config.read_file(fh)
     suite_name = config_path.split(os.path.sep)[-2]
     suite_dirs = _get_suite_dirs(suite_name)
     data_dir = suite_dirs.data_tests_dir
@@ -202,6 +202,9 @@ def configuration(request, tests_directory, log_level):
     if data_dir is not None:  # suite has its own database
         repository_url = _get_repository_url(request.config, suite_name,
                                              tests_directory)
+    elif suite_name == 'opensearcheo':
+        repository_url = _get_repository_url(request.config, "apiso",
+                                             tests_directory)
     else:  # suite uses the CITE database
         data_dir, export_dir = _get_cite_suite_dirs()
         repository_url = _get_repository_url(request.config, "cite",
@@ -383,7 +386,7 @@ def _get_table_name(suite, config, repository_url):
     ----------
     suite: str
         Name of the suite.
-    config: SafeConfigParser
+    config: ConfigParser
         Configuration for the suite.
     repository_url: str
         SQLAlchemy URL for the repository in use.
